[−][src]Enum unicode_types::cherokee::Cherokee
An enum to represent all characters in the Cherokee block.
Variants
LetterA\u{13a0}: 'Ꭰ'
LetterE\u{13a1}: 'Ꭱ'
LetterI\u{13a2}: 'Ꭲ'
LetterO\u{13a3}: 'Ꭳ'
LetterU\u{13a4}: 'Ꭴ'
LetterV\u{13a5}: 'Ꭵ'
LetterGa\u{13a6}: 'Ꭶ'
LetterKa\u{13a7}: 'Ꭷ'
LetterGe\u{13a8}: 'Ꭸ'
LetterGi\u{13a9}: 'Ꭹ'
LetterGo\u{13aa}: 'Ꭺ'
LetterGu\u{13ab}: 'Ꭻ'
LetterGv\u{13ac}: 'Ꭼ'
LetterHa\u{13ad}: 'Ꭽ'
LetterHe\u{13ae}: 'Ꭾ'
LetterHi\u{13af}: 'Ꭿ'
LetterHo\u{13b0}: 'Ꮀ'
LetterHu\u{13b1}: 'Ꮁ'
LetterHv\u{13b2}: 'Ꮂ'
LetterLa\u{13b3}: 'Ꮃ'
LetterLe\u{13b4}: 'Ꮄ'
LetterLi\u{13b5}: 'Ꮅ'
LetterLo\u{13b6}: 'Ꮆ'
LetterLu\u{13b7}: 'Ꮇ'
LetterLv\u{13b8}: 'Ꮈ'
LetterMa\u{13b9}: 'Ꮉ'
LetterMe\u{13ba}: 'Ꮊ'
LetterMi\u{13bb}: 'Ꮋ'
LetterMo\u{13bc}: 'Ꮌ'
LetterMu\u{13bd}: 'Ꮍ'
LetterNa\u{13be}: 'Ꮎ'
LetterHna\u{13bf}: 'Ꮏ'
LetterNah\u{13c0}: 'Ꮐ'
LetterNe\u{13c1}: 'Ꮑ'
LetterNi\u{13c2}: 'Ꮒ'
LetterNo\u{13c3}: 'Ꮓ'
LetterNu\u{13c4}: 'Ꮔ'
LetterNv\u{13c5}: 'Ꮕ'
LetterQua\u{13c6}: 'Ꮖ'
LetterQue\u{13c7}: 'Ꮗ'
LetterQui\u{13c8}: 'Ꮘ'
LetterQuo\u{13c9}: 'Ꮙ'
LetterQuu\u{13ca}: 'Ꮚ'
LetterQuv\u{13cb}: 'Ꮛ'
LetterSa\u{13cc}: 'Ꮜ'
LetterS\u{13cd}: 'Ꮝ'
LetterSe\u{13ce}: 'Ꮞ'
LetterSi\u{13cf}: 'Ꮟ'
LetterSo\u{13d0}: 'Ꮠ'
LetterSu\u{13d1}: 'Ꮡ'
LetterSv\u{13d2}: 'Ꮢ'
LetterDa\u{13d3}: 'Ꮣ'
LetterTa\u{13d4}: 'Ꮤ'
LetterDe\u{13d5}: 'Ꮥ'
LetterTe\u{13d6}: 'Ꮦ'
LetterDi\u{13d7}: 'Ꮧ'
LetterTi\u{13d8}: 'Ꮨ'
LetterDo\u{13d9}: 'Ꮩ'
LetterDu\u{13da}: 'Ꮪ'
LetterDv\u{13db}: 'Ꮫ'
LetterDla\u{13dc}: 'Ꮬ'
LetterTla\u{13dd}: 'Ꮭ'
LetterTle\u{13de}: 'Ꮮ'
LetterTli\u{13df}: 'Ꮯ'
LetterTlo\u{13e0}: 'Ꮰ'
LetterTlu\u{13e1}: 'Ꮱ'
LetterTlv\u{13e2}: 'Ꮲ'
LetterTsa\u{13e3}: 'Ꮳ'
LetterTse\u{13e4}: 'Ꮴ'
LetterTsi\u{13e5}: 'Ꮵ'
LetterTso\u{13e6}: 'Ꮶ'
LetterTsu\u{13e7}: 'Ꮷ'
LetterTsv\u{13e8}: 'Ꮸ'
LetterWa\u{13e9}: 'Ꮹ'
LetterWe\u{13ea}: 'Ꮺ'
LetterWi\u{13eb}: 'Ꮻ'
LetterWo\u{13ec}: 'Ꮼ'
LetterWu\u{13ed}: 'Ꮽ'
LetterWv\u{13ee}: 'Ꮾ'
LetterYa\u{13ef}: 'Ꮿ'
LetterYe\u{13f0}: 'Ᏸ'
LetterYi\u{13f1}: 'Ᏹ'
LetterYo\u{13f2}: 'Ᏺ'
LetterYu\u{13f3}: 'Ᏻ'
LetterYv\u{13f4}: 'Ᏼ'
LetterMv\u{13f5}: 'Ᏽ'
SmallLetterYe\u{13f8}: 'ᏸ'
SmallLetterYi\u{13f9}: 'ᏹ'
SmallLetterYo\u{13fa}: 'ᏺ'
SmallLetterYu\u{13fb}: 'ᏻ'
SmallLetterYv\u{13fc}: 'ᏼ'
SmallLetterMv\u{13fd}: 'ᏽ'
Methods
impl Cherokee[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case